ComputeFutureReservationInstanceProperties class final

Typed helper for the specific_sku_properties.instance_properties block of google_compute_future_reservation (derived from provider schema).

Annotations
  • @immutable

Constructors

ComputeFutureReservationInstanceProperties({TfArg<String>? locationHint, TfArg<String>? machineType, TfArg<num>? maintenanceFreezeDurationHours, ComputeFutureReservationMaintenanceInterval? maintenanceInterval, TfArg<String>? minCpuPlatform, List<ComputeFutureReservationGuestAccelerators>? guestAccelerators, List<ComputeFutureReservationLocalSsds>? localSsds})
const

Properties

guestAccelerators → List<ComputeFutureReservationGuestAccelerators>?
final
hashCode → int
The hash code for this object.
no setterinherited
localSsds → List<ComputeFutureReservationLocalSsds>?
final
locationHint → TfArg<String>?
final
machineType → TfArg<String>?
final
maintenanceFreezeDurationHours → TfArg<num>?
final
maintenanceInterval → ComputeFutureReservationMaintenanceInterval?
final
minCpuPlatform → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited