ComputeRegionNetworkPolicyTrafficClassificationRuleAction class final

Typed helper for the action block of google_compute_region_network_policy_traffic_classification_rule (derived from provider schema).

Annotations
  • @immutable

Properties

dscpMode → ComputeRegionNetworkPolicyTrafficClassificationRuleDscpMode?
final
dscpValue → TfArg<num>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficClass → ComputeRegionNetworkPolicyTrafficClassificationRuleTrafficClass?
final
type → ComputeRegionNetworkPolicyTrafficClassificationRuleType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited