DataformRepositoryReleaseConfigCodeCompilationConfig class final

Typed helper for the code_compilation_config block of google_dataform_repository_release_config (derived from provider schema).

Annotations
  • @immutable

Constructors

DataformRepositoryReleaseConfigCodeCompilationConfig({TfArg<String>? assertionSchema, TfArg<String>? databaseSuffix, TfArg<String>? defaultDatabase, TfArg<String>? defaultLocation, TfArg<String>? defaultSchema, TfArg<String>? schemaSuffix, TfArg<String>? tablePrefix, TfArg<Map<String, String>>? vars})
const

Properties

assertionSchema → TfArg<String>?
final
databaseSuffix → TfArg<String>?
final
defaultDatabase → TfArg<String>?
final
defaultLocation → TfArg<String>?
final
defaultSchema → TfArg<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaSuffix → TfArg<String>?
final
tablePrefix → TfArg<String>?
final
vars → TfArg<Map<String, String>>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited