DataformRepositoryWorkflowConfigInvocationConfig class final

Typed helper for the invocation_config block of google_dataform_repository_workflow_config (derived from provider schema).

Annotations
  • @immutable

Constructors

DataformRepositoryWorkflowConfigInvocationConfig({TfArg<bool>? fullyRefreshIncrementalTablesEnabled, TfArg<List<String>>? includedTags, RefTo<GoogleServiceAccount>? serviceAccount, TfArg<bool>? transitiveDependenciesIncluded, TfArg<bool>? transitiveDependentsIncluded, List<DataformRepositoryWorkflowConfigIncludedTargets>? includedTargets})
const

Properties

fullyRefreshIncrementalTablesEnabled → TfArg<bool>?
final
hashCode → int
The hash code for this object.
no setterinherited
includedTags → TfArg<List<String>>?
final
includedTargets → List<DataformRepositoryWorkflowConfigIncludedTargets>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount → RefTo<GoogleServiceAccount>?
final
transitiveDependenciesIncluded → TfArg<bool>?
final
transitiveDependentsIncluded → TfArg<bool>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited