DuplicateResourceError class final
Thrown by Stack.add when an entry with the same
(kind, terraformType, localName) triple is registered twice.
Constructors
- DuplicateResourceError({required ResourceKind kind, required String terraformType, required String localName})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ResourceKind
-
final
- localName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
- terraformType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited