SaasRuntimeUnitMaintenance class final

Typed helper for the maintenance block of google_saas_runtime_unit (derived from provider schema).

Annotations
  • @immutable

Constructors

SaasRuntimeUnitMaintenance({TfArg<String>? pinnedUntilTime})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
pinnedUntilTime → TfArg<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited