SecurityScannerScanConfigAuthentication class final
Typed helper for the authentication block of
google_security_scanner_scan_config (derived from provider schema).
- Annotations
-
- @immutable
Constructors
- SecurityScannerScanConfigAuthentication({SecurityScannerScanConfigCustomAccount? customAccount, SecurityScannerScanConfigGoogleAccount? googleAccount})
-
const
Properties
- customAccount → SecurityScannerScanConfigCustomAccount?
-
final
- googleAccount → SecurityScannerScanConfigGoogleAccount?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited