CesSecuritySettingsEndpointControlPolicy class final
Typed helper for the endpoint_control_policy block of
google_ces_security_settings (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
CesSecuritySettingsEndpointControlPolicy({TfArg<
List< ? allowedOrigins, CesSecuritySettingsEnforcementScope? enforcementScope})String> > -
const
Properties
-
allowedOrigins
→ TfArg<
List< ?String> > -
final
- enforcementScope → CesSecuritySettingsEnforcementScope?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited