FirebaseExtensionsInstanceConfig class final
Typed helper for the config block of
google_firebase_extensions_instance (derived from provider schema).
- Annotations
-
- @immutable
Constructors
Properties
-
allowedEventTypes
→ TfArg<
List< ?String> > -
final
-
eventarcChannel
→ TfArg<
String> ? -
final
-
extensionRef
→ TfArg<
String> -
final
-
extensionVersion
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
params
→ TfArg<
Map< String, String> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
systemParams
→ TfArg<
Map< ?String, String> > -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited