FirebaseHostingVersionRewrites class final
Typed helper for the config.rewrites block of
google_firebase_hosting_version (derived from provider schema).
- Annotations
-
- @immutable
Constructors
-
FirebaseHostingVersionRewrites({TfArg<
String> ? function, TfArg<String> ? glob, TfArg<String> ? path, TfArg<String> ? regex, FirebaseHostingVersionRun? run}) -
const
Properties
-
function
→ TfArg<
String> ? -
final
-
glob
→ TfArg<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
path
→ TfArg<
String> ? -
final
-
regex
→ TfArg<
String> ? -
final
- run → FirebaseHostingVersionRun?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited